==> Bencher-Scenarios-PERLANCARModuleList-0.02.tar.gz: Bencher-Scenarios-PERLANCARModuleList-0.02/lib/Bencher/Scenarios/PERLANCARModuleList.pm <==
package Bencher::Scenarios::PERLANCARModuleList;

our $DATE = '2017-01-25'; # DATE
our $VERSION = '0.02'; # VERSION

1;
# ABSTRACT: A collection of scenarios to benchmark PERLANCAR::Module::List

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::PERLANCARModuleList - A collection of scenarios to benchmark PERLANCAR::Module::List

=head1 VERSION

This document describes version 0.02 of Bencher::Scenarios::PERLANCARModuleList (from Perl distribution Bencher-Scenarios-PERLANCARModuleList), released on 2017-01-25.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::PERLANCARModuleList::ReturnPathOption>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-PERLANCARModuleList>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenario-PERLANCARModuleList>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-PERLANCARModuleList>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Bencher-Scenarios-PERLANCARModuleList-0.030.tar.gz: Bencher-Scenarios-PERLANCARModuleList-0.030/lib/Bencher/Scenarios/PERLANCARModuleList.pm <==
package Bencher::Scenarios::PERLANCARModuleList;

our $DATE = '2019-07-25'; # DATE
our $VERSION = '0.030'; # VERSION

1;
# ABSTRACT: A collection of scenarios to benchmark PERLANCAR::Module::List

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::PERLANCARModuleList - A collection of scenarios to benchmark PERLANCAR::Module::List

=head1 VERSION

This document describes version 0.030 of Bencher::Scenarios::PERLANCARModuleList (from Perl distribution Bencher-Scenarios-PERLANCARModuleList), released on 2019-07-25.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::PERLANCARModuleList::Startup>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-PERLANCARModuleList>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-PERLANCARModuleList>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-PERLANCARModuleList>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
